@@ -86,7 +86,8 @@ setClass("importer",
   contains=c("item.list","named.list","list"),
   representation(
     ptr="externalptr",
-    document = "character"
+    document = "character",
+    encoded = "character"
   )
 )
 
@@ -129,6 +130,13 @@ setClass("Stata.importer",
   )
 )
 
+setClass("Stata_new.importer",
+         contains="importer",
+         representation(
+             types = "integer"
+         )
+)
+
 setClass("codebook",
   contains="list"
 )
