@@ -8,7 +8,6 @@
 #include "memisc.h"
 #include "rofile.h"
 
-
 int _R_atoi(char *text){
   char *end_ptr;
   if(!strlen(text)) return NA_INTEGER; 
@@ -25,6 +24,55 @@ double _R_atof(char *text){
   else return result;
 }
 
+size_t Rgetline(char **lineptr, size_t *lenptr, FILE *file){
+
+  char *line = *lineptr;
+  size_t len = *lenptr;
+  
+  if (file == NULL) {
+        error("File pointer is null.");
+  }
+  int chunk_size = 128;
+  if(len < chunk_size) len = chunk_size;
+    
+  if(line == NULL){
+    line = (char *)R_alloc(len,sizeof(char));
+    if(line == NULL)
+      error("Could not allocate line pointer");
+    /* Rprintf("Initial buffer size: %d\n",len); */
+  }
+    
+  char ch = getc(file);
+  size_t n = 0;
+    
+  while((ch != '\n') && (ch != '\r') && (ch != EOF)){
+    /* Rprintf("Current char: %c\n",ch);
+     * Rprintf("Current buffer: %s\n",line); */
+    if(n == len){
+      /* Rprintf("Increasing buffer size\n"); */
+      char *tmp = (char *)R_alloc(len+chunk_size,sizeof(char));
+      if(tmp == NULL)
+        error("Could not extend buffer size");
+      memcpy(tmp,line,len);
+      line = tmp;
+      len += chunk_size;
+      /* Rprintf("New buffer size: %d\n",len); */
+    }
+    line[n] = ch;
+    n++;
+
+    ch = getc(file);
+  }
+  while((ch == '\n') || (ch == '\r')) ch = getc(file);
+  if((ch != '\n') && (ch != '\r') && (ch != EOF)) ungetc(ch,file);
+  
+  line[n] = '\0';
+  *lineptr = line;
+  *lenptr = len;
+  return n;
+}
+
+
 SEXP readfixed(SEXP s_file, SEXP what, SEXP s_nlines, SEXP s_start, SEXP s_stop){
   PROTECT(s_start = coerceVector(s_start,INTSXP));
   PROTECT(s_stop = coerceVector(s_stop,INTSXP));
@@ -34,8 +82,9 @@ SEXP readfixed(SEXP s_file, SEXP what, SEXP s_nlines, SEXP s_start, SEXP s_stop)
   int nvar = LENGTH(s_start);
   int *start = INTEGER(s_start);
   int *stop = INTEGER(s_stop);
-  int max_lenline = stop[nvar-1];
-  char *buffer = R_alloc(max_lenline+3,1);
+  size_t max_lenline = 0;
+  size_t cur_len;
+  char *buffer = NULL;
   char *item, *currdata;
   SEXP data;
   PROTECT(data=allocVector(VECSXP,nvar));
@@ -50,28 +99,17 @@ SEXP readfixed(SEXP s_file, SEXP what, SEXP s_nlines, SEXP s_start, SEXP s_stop)
     SET_VECTOR_ELT(data,j,lengthgets(x,n));
   }
   item = R_alloc(maxlen+1,1);
-#undef DEBUG
 #ifdef DEBUG
   Rprintf("Requested number of lines: %d\n",n);
 #endif  
   for(i = 0; i < n; i++){
-    memset(buffer,0,max_lenline+3);
-    buffer = fgets(buffer,max_lenline+3,f);
+    cur_len = Rgetline(&buffer,&max_lenline,f);
 #ifdef DEBUG
     Rprintf("Requested line length: %d\n",max_lenline);
     Rprintf("Actual line length: %d\n",strlen(buffer));
-    if(i == 0)
+    if(i < 3)
       Rprintf("Buffer: >>%s<<\n",buffer);
 #endif    
-    if(strlen(buffer)< max_lenline) {
-      int new_length = i;
-      for(j = 0; j < nvar; j++){
-        x = VECTOR_ELT(data,j);
-        SET_VECTOR_ELT(data,j,lengthgets(x,new_length));
-      }
-      n = new_length;
-      break;
-    }
     currdata = buffer;
     for(j = 0; j < nvar; j++){
       x = VECTOR_ELT(data,j);
@@ -97,20 +135,19 @@ SEXP readfixed(SEXP s_file, SEXP what, SEXP s_nlines, SEXP s_start, SEXP s_stop)
   return data;
 }
 
-SEXP countlines(SEXP s_file, SEXP s_maxlenline){
+SEXP countlines(SEXP s_file){
   FILE *f = rofile_FILE(s_file);
-  int max_lenline = asInteger(s_maxlenline);
-  char *buffer = R_alloc(max_lenline+3,1);
-  char *ret;
+  size_t max_lenline = 0;
+  size_t cur_len;
+  char *buffer = NULL;
   int i, n;
 
   for(i = 0;; i++){
-    memset(buffer,0,max_lenline+3);
-    ret = fgets(buffer,max_lenline+3,f);
+    cur_len = Rgetline(&buffer,&max_lenline,f);
 #ifdef DEBUG
     Rprintf("Line: %d\n",i);
 #endif    
-    if(ret == NULL || feof(f)) {
+    if(feof(f)) {
 #ifdef DEBUG
       Rprintf("Requested line length: %d\n",max_lenline);
       Rprintf("Actual line length: %d\n",strlen(buffer));
@@ -139,8 +176,9 @@ SEXP readfixedslice(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_cases, SEXP s_st
   for(j = 0; j < LENGTH(s_vars); j++) m += LOGICAL(s_vars)[j];
   int *start = INTEGER(s_start);
   int *stop = INTEGER(s_stop);
-  int max_lenline = stop[nvar-1];
-  char *buffer = R_alloc(max_lenline+3,1);
+  size_t max_lenline = 0;
+  size_t cur_len;
+  char *buffer = NULL;
   char *item, *currdata;
 
   SEXP data;
@@ -161,22 +199,12 @@ SEXP readfixedslice(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_cases, SEXP s_st
   item = R_alloc(maxlen+1,1);
   ii = 0;
   for(i = 0; i < ncases; i++){
-    memset(buffer,0,max_lenline+3);
-    buffer = fgets(buffer,max_lenline+3,f);
+    cur_len = Rgetline(&buffer,&max_lenline,f);
 #ifdef DEBUG
     Rprintf("Requested line length: %d\n",max_lenline);
     Rprintf("Actual line length: %d\n",strlen(buffer));
     Rprintf("Buffer: >>%s<<\n",buffer);
 #endif
-    if(strlen(buffer)< max_lenline) {
-      int new_length = i;
-      for(j = 0; j < m; j++){
-        x = VECTOR_ELT(data,j);
-        SET_VECTOR_ELT(data,j,lengthgets(x,new_length));
-      }
-      n = new_length;
-      break;
-    }
     if(LOGICAL(s_cases)[i]){
       currdata = buffer;
       k = 0;
@@ -231,8 +259,9 @@ SEXP readfixedchunk(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_nlines, SEXP s_s
   for(j = 0; j < LENGTH(s_vars); j++) m += LOGICAL(s_vars)[j];
   int *start = INTEGER(s_start);
   int *stop = INTEGER(s_stop);
-  int max_lenline = stop[nvar-1];
-  char *buffer = R_alloc(max_lenline+3,1);
+  size_t max_lenline = 0;
+  size_t cur_len;
+  char *buffer = NULL;
   char *item, *currdata;
   SEXP data;
   PROTECT(data=allocVector(VECSXP,m));
@@ -255,23 +284,13 @@ SEXP readfixedchunk(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_nlines, SEXP s_s
   Rprintf("Requested number of lines: %d\n",n);
 #endif  
   for(i = 0; i < n; i++){
-    memset(buffer,0,max_lenline+3);
-    buffer = fgets(buffer,max_lenline+3,f);
+    cur_len = Rgetline(&buffer,&max_lenline,f);
 #ifdef DEBUG
     Rprintf("Requested line length: %d\n",max_lenline);
     Rprintf("Actual line length: %d\n",strlen(buffer));
     if(i == 0)
       Rprintf("Buffer: >>%s<<\n",buffer);
 #endif    
-    if(strlen(buffer)< max_lenline) {
-      int new_length = i;
-      for(j = 0; j < m; j++){
-        x = VECTOR_ELT(data,j);
-        SET_VECTOR_ELT(data,j,lengthgets(x,new_length));
-      }
-      n = new_length;
-      break;
-    }
     currdata = buffer;
 		k = 0;
     for(j = 0; j < nvar; j++){
